@@ -1,5 +1,5 @@
 x = 3  # input
 y = 5  # input
-input('What is your name?')  # ignore
+print('What is your name?')  # ignore
 z = x + y  # output
 z = 100000   # ignore
\ No newline at end of file
